package com.jiuqi.dna.ide.designer.workflow;

import com.jiuqi.dna.ide.designer.DesignerBase;
import com.jiuqi.dna.ide.designer.elements.IDesignerElement;
import com.jiuqi.dna.ide.designer.elements.IFigureElement;
import com.jiuqi.dna.ide.designer.elements.ILinkElement;
import com.jiuqi.dna.ide.designer.elements.IRootElement;
import com.jiuqi.dna.ide.designer.elements.LinkElement;
import com.jiuqi.dna.ide.designer.events.BendpointEvent;
import com.jiuqi.dna.ide.designer.events.FigureEvent;
import com.jiuqi.dna.ide.designer.events.IBendpointListener;
import com.jiuqi.dna.ide.designer.events.IFigureListener;
import com.jiuqi.dna.ide.designer.events.ILinkListener;
import com.jiuqi.dna.ide.designer.events.LinkEvent;
import java.util.ArrayList;
import java.util.Iterator;
import org.eclipse.draw2d.geometry.Point;

/* loaded from: com_jiuqi_dna_ide_designer_workflow.jar:com/jiuqi/dna/ide/designer/workflow/WorkflowDesignerBase.class */
public class WorkflowDesignerBase extends DesignerBase {
    private ArrayList<ILinkListener> linkListeners = new ArrayList<>();
    private ArrayList<IBendpointListener> bendpointListeners = new ArrayList<>();

    public IRootElement getRootElement() {
        IRootElement rootElement = super.getRootElement();
        return rootElement;
    }

    public <T extends IDesignerElement> T createElement(Class<T> cls) {
        if (cls == ILinkElement.class || cls == LinkElement.class) {
            LinkElement linkElement = new LinkElement();
            linkElement.setDesigner(this);
            return linkElement;
        }
        return (T) super.createElement(cls);
    }

    public void addLinkListener(ILinkListener listener) {
        this.linkListeners.add(listener);
    }

    public void removeLinkListener(ILinkListener listener) {
        this.linkListeners.remove(listener);
    }

    public ILinkListener[] getLinkListeners() {
        ILinkListener[] listeners = new ILinkListener[this.linkListeners.size()];
        return (ILinkListener[]) this.linkListeners.toArray(listeners);
    }

    public void addBendpointListener(IBendpointListener listener) {
        this.bendpointListeners.add(listener);
    }

    public void removeBendpointListener(IBendpointListener listener) {
        this.bendpointListeners.remove(listener);
    }

    public IBendpointListener[] getBendpointListeners() {
        IBendpointListener[] listeners = new IBendpointListener[this.bendpointListeners.size()];
        return (IBendpointListener[]) this.bendpointListeners.toArray(listeners);
    }

    public void fireLinkCreate(ILinkElement link) {
        if (!isEventEnabled()) {
            return;
        }
        LinkEvent event = new LinkEvent(this);
        event.link = link;
        Iterator<ILinkListener> it = this.linkListeners.iterator();
        while (it.hasNext()) {
            ILinkListener listener = it.next();
            listener.linkCreate(event);
        }
    }

    public void fireLinkDelete(ILinkElement link) {
        if (!isEventEnabled()) {
            return;
        }
        LinkEvent event = new LinkEvent(this);
        event.link = link;
        Iterator<ILinkListener> it = this.linkListeners.iterator();
        while (it.hasNext()) {
            ILinkListener listener = it.next();
            listener.linkDelete(event);
        }
    }

    public void fireLinkChange(ILinkElement link, IFigureElement oldNode, boolean sourceChanged) {
        if (!isEventEnabled()) {
            return;
        }
        LinkEvent event = new LinkEvent(this);
        event.link = link;
        event.node = oldNode;
        event.sourceChanged = sourceChanged;
        event.targetChanged = !sourceChanged;
        Iterator<ILinkListener> it = this.linkListeners.iterator();
        while (it.hasNext()) {
            ILinkListener listener = it.next();
            listener.linkChange(event);
        }
    }

    public void fireSourceLinkAdd(IFigureElement element, ILinkElement link) {
        if (!isEventEnabled()) {
            return;
        }
        FigureEvent event = new FigureEvent(this);
        event.element = element;
        event.link = link;
        for (IFigureListener listener : getFigureListeners()) {
            listener.figureSourceLinkAdd(event);
        }
    }

    public void fireSourceLinkRemove(IFigureElement element, ILinkElement link) {
        if (!isEventEnabled()) {
            return;
        }
        FigureEvent event = new FigureEvent(this);
        event.element = element;
        event.link = link;
        for (IFigureListener listener : getFigureListeners()) {
            listener.figureSourceLinkRemove(event);
        }
    }

    public void fireTargetLinkAdd(IFigureElement element, ILinkElement link) {
        if (!isEventEnabled()) {
            return;
        }
        FigureEvent event = new FigureEvent(this);
        event.element = element;
        event.link = link;
        for (IFigureListener listener : getFigureListeners()) {
            listener.figureTargetLinkAdd(event);
        }
    }

    public void fireTargetLinkRemove(IFigureElement element, ILinkElement link) {
        if (!isEventEnabled()) {
            return;
        }
        FigureEvent event = new FigureEvent(this);
        event.element = element;
        event.link = link;
        for (IFigureListener listener : getFigureListeners()) {
            listener.figureTargetLinkRemove(event);
        }
    }

    public void fireBendpointCreate(ILinkElement link, int index, Point point) {
        if (!isEventEnabled()) {
            return;
        }
        BendpointEvent event = new BendpointEvent(this);
        event.link = link;
        event.index = index;
        event.point = point;
        Iterator<IBendpointListener> it = this.bendpointListeners.iterator();
        while (it.hasNext()) {
            IBendpointListener listener = it.next();
            listener.bendpointCreate(event);
        }
    }

    public void fireBendpointDelete(ILinkElement link, int index, Point point) {
        if (!isEventEnabled()) {
            return;
        }
        BendpointEvent event = new BendpointEvent(this);
        event.link = link;
        event.index = index;
        event.point = point;
        Iterator<IBendpointListener> it = this.bendpointListeners.iterator();
        while (it.hasNext()) {
            IBendpointListener listener = it.next();
            listener.bendpointDelete(event);
        }
    }

    public void fireBendpointMove(ILinkElement link, int index, Point point) {
        if (!isEventEnabled()) {
            return;
        }
        BendpointEvent event = new BendpointEvent(this);
        event.link = link;
        event.index = index;
        event.point = point;
        Iterator<IBendpointListener> it = this.bendpointListeners.iterator();
        while (it.hasNext()) {
            IBendpointListener listener = it.next();
            listener.bendpointMove(event);
        }
    }

    public boolean fireVerifyLinkCreate(ILinkElement link) {
        if (!isEventEnabled()) {
            return true;
        }
        LinkEvent event = new LinkEvent(this);
        event.link = link;
        Iterator<ILinkListener> it = this.linkListeners.iterator();
        while (it.hasNext()) {
            ILinkListener listener = it.next();
            if (!listener.verifyCreate(event)) {
                return false;
            }
        }
        return true;
    }

    public boolean fireVerifyLinkDelete(ILinkElement link) {
        if (!isEventEnabled()) {
            return true;
        }
        LinkEvent event = new LinkEvent(this);
        event.link = link;
        Iterator<ILinkListener> it = this.linkListeners.iterator();
        while (it.hasNext()) {
            ILinkListener listener = it.next();
            if (!listener.verifyDelete(event)) {
                return false;
            }
        }
        return true;
    }

    public boolean fireVerifyLinkChange(ILinkElement link, IFigureElement node, boolean sourceChanged) {
        if (!isEventEnabled()) {
            return true;
        }
        LinkEvent event = new LinkEvent(this);
        event.link = link;
        event.node = node;
        event.sourceChanged = sourceChanged;
        event.targetChanged = !sourceChanged;
        Iterator<ILinkListener> it = this.linkListeners.iterator();
        while (it.hasNext()) {
            ILinkListener listener = it.next();
            if (!listener.verifyChange(event)) {
                return false;
            }
        }
        return true;
    }

    public boolean fireVerifyBendpointCreate(ILinkElement link, int index, Point point) {
        if (!isEventEnabled()) {
            return true;
        }
        BendpointEvent event = new BendpointEvent(this);
        event.link = link;
        event.index = index;
        event.point = point;
        Iterator<IBendpointListener> it = this.bendpointListeners.iterator();
        while (it.hasNext()) {
            IBendpointListener listener = it.next();
            if (!listener.verifyCreate(event)) {
                return false;
            }
        }
        return true;
    }

    public boolean fireVerifyBendpointDelete(ILinkElement link, int index) {
        if (!isEventEnabled()) {
            return true;
        }
        BendpointEvent event = new BendpointEvent(this);
        event.link = link;
        event.index = index;
        Iterator<IBendpointListener> it = this.bendpointListeners.iterator();
        while (it.hasNext()) {
            IBendpointListener listener = it.next();
            if (!listener.verifyDelete(event)) {
                return false;
            }
        }
        return true;
    }

    public boolean fireVerifyBendpointMove(ILinkElement link, int index, Point point) {
        if (!isEventEnabled()) {
            return true;
        }
        BendpointEvent event = new BendpointEvent(this);
        event.link = link;
        event.index = index;
        event.point = point;
        Iterator<IBendpointListener> it = this.bendpointListeners.iterator();
        while (it.hasNext()) {
            IBendpointListener listener = it.next();
            if (!listener.verifyChange(event)) {
                return false;
            }
        }
        return true;
    }
}
